import { query, operationStore, subscription } from '@urql/svelte';
import { writable } from 'svelte/store'; 
import { doFetch } from '../../helpers';
const defaultState = {loggedIn:false, loading:false, profile: null, error: null}
const { subscribe, set, update } = writable(defaultState);





async function logStat({ type = "Weight", recordedTs, value }) {
    return await doFetch({
        url: 'http://localhost/v1/api/stats',
        method: 'PUT',
        body: {
            type,
            recordedTs,
            value
        }
    });
}

const getStat = ({ start = '2020-01-01T00:00:00',types = ['Weight', 'Calories', 'Height'] })  =>
     operationStore(`
        query GetStats($types: [logtype!] = ["Weight"], $start: timestamp! = "2020-01-01T00:00:00") {
            stats_log(where: {
                logtype: {_in: $types },
                recordedts: {_gte: $start}
            },
            order_by: { recordedts: desc }) {
                value
                logtype
                recordedts
                id
            }
        }`,
        { start, types },
        {
            requestPolicy: "cache-and-network",
            fetchOptions: {
                headers: {
                    'Authorization': `Bearer ${localStorage.getItem('jwt')}`
                }
            }
        });



export default { subscribe, logStat, getStat };