import Cookies from 'js-cookie';
import { writable } from 'svelte/store';
import { doFetch } from '../../helpers';

const defaultState = { loggedIn: false, loading: false, profile: null, error: null, token: null };

const { subscribe, set, update } = writable(defaultState);

const logout = () => {
    localStorage.removeItem('jwt');
    Cookies.remove('jwt', { path: '/', domain: 'localhost' });
    set(defaultState);
    location.pathname !== "/" && location.replace("/");
}

const load = async () => {
    try {
        update(p => ({ ...p, loading: true}));
        
        const {success, payload} = await doFetch({ url:"http://localhost:3000/v1/api/user" });

        if (!success) {
            set({ ...defaultState, error: payload });
            logout();
            return
        }

        update(() => ({ ...defaultState, loggedIn:true, profile: payload, token: localStorage.getItem('jwt') }));
    } catch (e) {
        set({ ...defaultState, error: e.message });
        logout();
    }
}

const login = async ({ email, password }) => {
    try {
        update(p => ({ ...p, loading: true}));
        const { success, payload } = await doFetch({
            url: "http://localhost:3000/v1/api/user/auth",
            method: "POST",
            headers: {
                'Content-Type': 'application/json'
            },
            body: { email, password }
        });


        if (!success) {
            set({ ...defaultState, error: payload });
            logout();
            return
        }


        set({ ...defaultState, loggedIn:true, profile: payload.profile, token: payload.token });
        localStorage.setItem('jwt', payload.token)
    } catch (e) {
        set({ ...defaultState, error: e.message });
        console.trace(e);
    }
}

export default { subscribe, login, logout, load };